
// -----------------------------------------------------------
//                     Line canvas
// -----------------------------------------------------------
function line_onDraw(me, eventInfo)
{
    // define the context 2D
    // "me" refer to canvas widget with OnDraw event triggered    
    var ctx = me.context2d;
    
    // drawing the line from 0,0 to 100,100
    ctx.moveTo(0,0);
    ctx.lineTo(100,100);
    ctx.strokeStyle="#0570B2";
    ctx.stroke(); 
}


// -----------------------------------------------------------
//                     Circle canvas
// -----------------------------------------------------------
function circle_onDraw(me, eventInfo)
{
    // define the context 2D
    // "me" refer to canvas widget with OnDraw event triggered
    var ctx = me.context2d;

    // define the Path
    ctx.beginPath();
    ctx.arc(me.width/2, me.height/2, me.height/3, 0, 360*Math.PI/180, false);
    ctx.closePath();
    
    // define the stroke instead of fill
    ctx.strokeStyle="#0570B2";
    ctx.stroke();
}


// -----------------------------------------------------------
//                     Rect canvas
// -----------------------------------------------------------
function rect_onDraw(me, eventInfo)
{
    // define the context 2D
    // "me" refer to canvas widget with OnDraw event triggered
    var ctx = me.context2d;
    
    // create gradient
    var grd = ctx.createRadialGradient(85,50,10,90,60,100);
    grd.addColorStop(0,"#0570B2");
    grd.addColorStop(1,"#FFFFFF");
    
    // fill with gradient
    ctx.fillStyle = grd;
    ctx.fillRect(10,10,150,80); 
    
}

// -----------------------------------------------------------
//                    Pie Chart canvas
// -----------------------------------------------------------

// piechart widget is referred outside instead of using "me"
// because piechart canvas widget have to be updated during runtime
var pieCanvas = page.getWidget("piechart");

// Function to draw a slice
function drawSegment(canvas, context, startAngle, endAngle, color1, color2)
{
    // begin path to draw a pie slice (an arc with a line)
    context.beginPath();
    context.moveTo(canvas.width/2, canvas.height/2);
    context.arc(canvas.width/2, canvas.height/2, 90, startAngle*Math.PI/180, endAngle*Math.PI/180, false);
    context.lineTo(canvas.width/2, canvas.height/2);
    context.closePath();

    // add a gradient to the slice
    var grd = context.createLinearGradient(0, 0, canvas.width, canvas.height);
    grd.addColorStop(0, color1);   
    grd.addColorStop(1, color2);

    // fill circle with the gradient
    context.fillStyle = grd;
    context.fill();
}

// Function called by OnDraw event of piechart canvas widget
function piechart_onDraw(me, eventInfo)
{
    var ctx = pieCanvas.context2d;
    var value1 = 360 * (page.getWidget("percent1").getProperty("value"))/100;
    var value2 = 360 * (page.getWidget("percent2").getProperty("value"))/100;
    
    drawSegment(pieCanvas, ctx, 0, value1,"#454545","#0570B2");
    drawSegment(pieCanvas, ctx, value1, value1+value2,"#454545","#EAC300");
    drawSegment(pieCanvas, ctx, value1+value2, 360,"#454545","#FF5353");  
}
    
// Function called by the update button.
// This button allow to update the pie chart when percent values are changed
function UpdateButton_onMouseClick(me, eventInfo)
{
    pieCanvas.update();
}


